Install all package dependencies from yaml file for building image purposes
Source:R/build_tools.R
installAllDeps.RdInstall all package dependencies from yaml file for building image purposes
Usage
installAllDeps(
additionalRepos = NULL,
base_dir = "/mnt/vol",
use_ssh = FALSE,
test_mode = FALSE
)Examples
installAllDeps(
base_dir = system.file(package = "gDRstyle", "testdata"),
test_mode = TRUE
)
#> $testthat
#> $testthat$source
#> [1] "CRAN"
#>
#> $testthat$ver
#> [1] ">= 3.0.0"
#>
#>
#> $R
#> $R$source
#> [1] "CRAN"
#>
#> $R$ver
#> [1] ">= 4.2"
#>
#>